# Changelog

## 0.6.0 (2025-12-17)

Full Changelog: [v0.5.0...v0.6.0](https://github.com/violetbuse/rocktick-python/compare/v0.5.0...v0.6.0)

### Features

* **api:** added tenant id to client settings ([fa64303](https://github.com/violetbuse/rocktick-python/commit/fa643031303e769f122bfeeb82c145f2bdec720c))


### Chores

* **internal:** add missing files argument to base client ([1dcd778](https://github.com/violetbuse/rocktick-python/commit/1dcd778d7d9c168ae6794bf596ed339691633e9c))
* speedup initial import ([fa0591d](https://github.com/violetbuse/rocktick-python/commit/fa0591da49172b00e4141cd5e852fc7f27faa1cc))


### Refactors

* **internal:** switch from rye to uv ([c418694](https://github.com/violetbuse/rocktick-python/commit/c418694f535c76300a4cb4a6a75d9f0c9ca70dfa))

## 0.5.0 (2025-12-15)

Full Changelog: [v0.1.20...v0.5.0](https://github.com/violetbuse/rocktick-python/compare/v0.1.20...v0.5.0)

### Features

* **api:** api update ([3d65476](https://github.com/violetbuse/rocktick-python/commit/3d65476589efb45ddb0c7f2f16b46556e16bf225))
* **api:** changed models request and response to HttpRequest and HttpResponse ([3e324fc](https://github.com/violetbuse/rocktick-python/commit/3e324fc29ddf07766f1f6c4401f08eca2c721e67))


### Bug Fixes

* **api:** changed names also to http_request and http_response ([4d59cf9](https://github.com/violetbuse/rocktick-python/commit/4d59cf92fe5890f9a171c9b1a5706d5873d5d48f))

## 0.1.20 (2025-12-14)

Full Changelog: [v0.0.1...v0.1.20](https://github.com/violetbuse/rocktick-python/compare/v0.0.1...v0.1.20)

### Features

* **api:** changed local dev url port ([ff84fad](https://github.com/violetbuse/rocktick-python/commit/ff84fade77015ef110e3edea573742fb6e0b205d))


### Chores

* configure new SDK language ([1af9dad](https://github.com/violetbuse/rocktick-python/commit/1af9dad5ccc10bbeeaf5795e48715ff0850afca6))
* update SDK settings ([55f2206](https://github.com/violetbuse/rocktick-python/commit/55f22063d854b20930b7495284436a69209eed94))
* update SDK settings ([6832898](https://github.com/violetbuse/rocktick-python/commit/68328987164caf77785dd4fc76e75adcf8cb177e))
